<?php
/**
 * Features options.
 *
 * @package Junior Kids
 */

$default = junior_kids_get_default_theme_options();

// Features Section
$wp_customize->add_section( 'section_home_features',
	array(
		'title'      => __( 'Features Section', 'junior-kids' ),
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);

$wp_customize->add_setting( 'theme_options[disable_features_section]',
	array(
		'default'           => $default['disable_features_section'],
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'Kids_education_bell_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Junior_Kids_Switch_Control( $wp_customize, 'theme_options[disable_features_section]',
    array(
		'label' 			=> __('Enable/Disable Features Section', 'junior-kids'),
		'section'    		=> 'section_home_features',
		 'settings'  		=> 'theme_options[disable_features_section]',
		'on_off_label' 		=> junior_kids_switch_options(),
    )
) );


// Cta Background Image
$wp_customize->add_setting('theme_options[background_features_section]', 
	array(
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'kids_education_bell_sanitize_image'
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'theme_options[background_features_section]', 
	array(
	'label'       => __('Background Image', 'junior-kids'),
	'section'     => 'section_home_features',   
	'settings'    => 'theme_options[background_features_section]',		
	'active_callback' => 'kids_education_bell_features_active',
	'type'        => 'image',
	)
	)
);

//Features Section title
$wp_customize->add_setting('theme_options[features_title]', 
	array(
	'default'           => $default['features_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[features_title]', 
	array(
	'label'       => __('Section Title', 'junior-kids'),
	'section'     => 'section_home_features',   
	'settings'    => 'theme_options[features_title]',
	'active_callback' => 'kids_education_bell_features_active',		
	'type'        => 'text'
	)
);

//Features Section Subtitle
$wp_customize->add_setting('theme_options[features_subtitle]', 
	array(
	'default'           => $default['features_subtitle'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_textarea_field'
	)
);

$wp_customize->add_control('theme_options[features_subtitle]', 
	array(
	'label'       => __('Section Sub Title', 'junior-kids'),
	'section'     => 'section_home_features',   
	'settings'    => 'theme_options[features_subtitle]',
	'active_callback' => 'kids_education_bell_features_active',		
	'type'        => 'textarea'
	)
);


// Number of items
$wp_customize->add_setting('theme_options[features_excerpt_length]', 
	array(
	'default' 			=> $default['features_excerpt_length'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'kids_education_bell_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[features_excerpt_length]', 
	array(
	'label'       => __('Excerpt Length', 'junior-kids'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 1000.', 'junior-kids'),
	'section'     => 'section_home_features',   
	'settings'    => 'theme_options[features_excerpt_length]',		
	'type'        => 'number',
	'active_callback' => 'kids_education_bell_features_active',
	'input_attrs' => array(
			'min'	=> 0,
			'max'	=> 1000,
			'step'	=> 1,
		),
	)
);

$number_of_features_items = junior_kids_get_option( 'number_of_features_items' );

for( $i=1; $i<=$number_of_features_items; $i++ ){

	//
	$wp_customize->add_setting('theme_options[features_post_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'Kids_education_bell_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[features_post_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Post #%1$s', 'junior-kids'), $i),
		'section'     => 'section_home_features',   
		'settings'    => 'theme_options[features_post_'.$i.']',		
		'type'        => 'select',
		'choices'	  => junior_kids_post_choices(),
		'active_callback' => 'kids_education_bell_features_active',
		)
	);
}

// Cta Button Text
$wp_customize->add_setting('theme_options[features_button_label]', 
	array(
	'default' 			=> $default['features_button_label'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[features_button_label]', 
	array(
	'label'       => __('Button Label', 'junior-kids'),
	'section'     => 'section_home_features',   
	'settings'    => 'theme_options[features_button_label]',	
	'active_callback' => 'kids_education_bell_features_active',	
	'type'        => 'text'
	)
);